package com.sibatel.solarapp.data

import android.util.Log
import com.sibatel.solarapp.data.model.mobil.Mobil
import com.sibatel.solarapp.data.model.mobil.MobilResponse
import com.sibatel.solarapp.data.model.solar.pengambilansolar.PengambilanSolar
import com.sibatel.solarapp.data.model.solar.pengambilansolar.PengambilanSolarResponse
import com.sibatel.solarapp.data.model.solar.penggunaansolar.PenggunaanSolar
import com.sibatel.solarapp.data.model.solar.penggunaansolar.PenggunaanSolarResponse
import com.sibatel.solarapp.data.model.tower.Maintenance
import com.sibatel.solarapp.data.model.tower.MaintenanceResponse
import com.sibatel.solarapp.data.model.user.User
import com.sibatel.solarapp.data.model.user.UserResponse
import com.sibatel.solarapp.network.RetrofitClient
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class RemoteDataSource {
    companion object{

        @Volatile
        private var instance : RemoteDataSource? = null

        fun getInstance(): RemoteDataSource =
            instance ?: synchronized(this){
                instance ?: RemoteDataSource()
            }
    }

    fun getMobilData(callback: loadDataMobilListCallback){
        RetrofitClient.apiInstance
            .getMobileData()
            .enqueue(object : Callback<MobilResponse> {
                override fun onResponse(
                    call: Call<MobilResponse>,
                    response: Response<MobilResponse>
                ) {
                    callback.onLoadMobil(response.body()?.results)
                }

                override fun onFailure(call: Call<MobilResponse>, t: Throwable) {
                    t.message?.let { Log.d("error Server", it) }
                }
            })
    }

    fun getUserData(callback: loadDataUserListCallback){
        RetrofitClient.apiInstance
            .getAllUser()
            .enqueue(object : Callback<UserResponse>{
                override fun onResponse(
                    call: Call<UserResponse>,
                    response: Response<UserResponse>
                ) {
                    callback.onLoadUser(response.body()?.result)
                }

                override fun onFailure(call: Call<UserResponse>, t: Throwable) {
                    t.message?.let { Log.d("error Server", it) }
                }
            })
    }

    fun getPengambilanSolarData(id:Int,callback: loadDataPengambilanSolarCallback){
        RetrofitClient.apiInstance
            .getAllPengambilanSolar(id)
            .enqueue(object : Callback<PengambilanSolarResponse>{
                override fun onResponse(
                    call: Call<PengambilanSolarResponse>,
                    response: Response<PengambilanSolarResponse>
                ) {
                    callback.onLoadPengambilanSolar(response.body()?.result)
                }

                override fun onFailure(call: Call<PengambilanSolarResponse>, t: Throwable) {
                    t.message?.let { Log.d("error Server", it) }
                }

            })
    }

    fun getPenggunaanSolarData(id:Int,callback: loadDataPenggunaanSolarCallback){
            RetrofitClient.apiInstance
                .getAllPenggunaanSolar(id)
                .enqueue(object : Callback<PenggunaanSolarResponse>{
                    override fun onResponse(
                        call: Call<PenggunaanSolarResponse>,
                        response: Response<PenggunaanSolarResponse>
                    ) {
                        callback.onLoadPenggunaanSolar(response.body()?.result)
                    }

                    override fun onFailure(call: Call<PenggunaanSolarResponse>, t: Throwable) {
                        t.message?.let { Log.d("error Server", it) }
                    }

                })
    }

    fun getMaintenanceData(id: Int, callback: loadDataMaintenanceCallback){
        RetrofitClient.apiInstance
            .getAllMaintenance(id)
            .enqueue(object : Callback<MaintenanceResponse>{
                override fun onResponse(
                    call: Call<MaintenanceResponse>,
                    response: Response<MaintenanceResponse>
                ) {
                    callback.onLoadMaintenance(response.body()?.result)
                }

                override fun onFailure(call: Call<MaintenanceResponse>, t: Throwable) {
                    t.message?.let { Log.d("error Server", it) }
                }

            })
    }

    interface loadDataMobilListCallback{
        fun onLoadMobil(response: ArrayList<Mobil>?)
    }

    interface loadDataUserListCallback{
        fun onLoadUser(response: ArrayList<User>?)
    }

    interface loadDataPengambilanSolarCallback{
        fun onLoadPengambilanSolar(response: ArrayList<PengambilanSolar>?)
    }

    interface loadDataPenggunaanSolarCallback{
        fun onLoadPenggunaanSolar(response: ArrayList<PenggunaanSolar>?)
    }

    interface loadDataMaintenanceCallback{
        fun onLoadMaintenance(response: ArrayList<Maintenance>?)
    }
}