package com.sibatel.solarapp.ui

import android.content.Intent
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.util.Log
import android.view.Menu
import android.view.MenuItem
import android.view.View
import android.widget.AdapterView
import android.widget.ArrayAdapter
import android.widget.Spinner
import android.widget.Toast
import com.sibatel.solarapp.R
import com.sibatel.solarapp.data.model.solar.pengambilansolar.PengambilanSolarResponse
import com.sibatel.solarapp.data.model.tower.TowerResponse
import com.sibatel.solarapp.databinding.ActivityMainBinding
import com.sibatel.solarapp.network.RetrofitClient
import com.sibatel.solarapp.ui.keuangan.Keuangan
import com.sibatel.solarapp.ui.maintenance.MaintenanceActivity
import com.sibatel.solarapp.ui.mentoring.MentoringSolar
import com.sibatel.solarapp.ui.mobil.DataMobil
import com.sibatel.solarapp.ui.user.Profil
import com.sibatel.solarapp.utils.ProgressBarAnimation
import com.sibatel.solarapp.utils.SharedPref
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response

class MainActivity : AppCompatActivity() {

    private lateinit var binding : ActivityMainBinding
    private lateinit var sharedPref: SharedPref
    private lateinit var site: Spinner

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        supportActionBar?.elevation = 0f
        sharedPref = SharedPref(this)

        binding = ActivityMainBinding.inflate(layoutInflater)
        setContentView(binding.root)


            if(sharedPref.getRole1().equals("scd") || sharedPref.getRole1().equals("timkorektif") || sharedPref.getRole1().equals("maintenance")){
                binding.btnMentoring.setOnClickListener{
                    val intent = Intent(this, MentoringSolar::class.java)
                    startActivity(intent)
                }
            }else{
                    binding.btnMentoring.setOnClickListener{
                        Toast.makeText(getApplicationContext(),"Maaf menuh hanya dapat diakses oleh Tim Korektif, Maintenance, dan SCD" ,
                            Toast.LENGTH_LONG).show()
                    }
            }

        if(sharedPref.getRole1().equals("maintenance")){
            binding.btnMaintenance.visibility = View.VISIBLE
        }else{
            binding.btnMaintenance.visibility = View.GONE
        }

        binding.btnMaintenance.setOnClickListener{
            val intent = Intent(this, MaintenanceActivity::class.java)
            startActivity(intent)
        }


        binding.btnMobil.setOnClickListener{
            val intent = Intent(this, DataMobil::class.java)
            startActivity(intent)
        }

        binding.btnKeuangan.setOnClickListener{
            val intent = Intent(this, Keuangan::class.java)
            startActivity(intent)
        }

        var allTower = ArrayList<String>()
        allTower.add("Pilih Site")

        RetrofitClient.apiInstance.getAllPendonorSite().enqueue(object : Callback<TowerResponse> {
            override fun onResponse(call: Call<TowerResponse>, response: Response<TowerResponse>) {
                if (response.isSuccessful){
                    response.body()?.result?.forEach {
                        it?.namaTower?.let { it1 -> allTower.add(it1) }
                    }
                }
            }

            override fun onFailure(call: Call<TowerResponse>, t: Throwable) {

            }

        })

        site = binding.site

        val adapter = ArrayAdapter<String>(this, android.R.layout.simple_spinner_dropdown_item, allTower)
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item)
        site.adapter = adapter

        site.onItemSelectedListener = object : AdapterView.OnItemSelectedListener{
            override fun onItemSelected(p0: AdapterView<*>?, p1: View?, p2: Int, p3: Long) {
                if (p2 == 0){
                    binding.txtTotalSolar.text = "0"
                    binding.txtTotalSolarDiambil.text = "0"
                    binding.statsProgressbar.progress = 0
                    binding.statsProgressbar2.progress = 0
                    binding.numberOfCalories.text = "0"
                    binding.numberOfCalories2.text = "0"
                }else{
                    RetrofitClient.apiInstance.dafarPengambilanSolar(p0?.getItemAtPosition(p2).toString())
                        .enqueue(object : Callback<PengambilanSolarResponse>{
                            override fun onResponse(
                                call: Call<PengambilanSolarResponse>,
                                response: Response<PengambilanSolarResponse>
                            ) {
                                if (response.isSuccessful){
                                    if (response.body()?.result?.isNotEmpty()!!){
                                        var total = 0.0
                                        var ttl = 0.0
                                        response.body()?.result?.forEach {
                                            total = String.format("%.0f", it?.jlhPendonorSdh.toString().toDouble()).toDouble()
                                            ttl += String.format("%.0f", it?.jlhSolarDiambil.toString().toDouble()).toDouble()
                                        }

                                        binding.txtTotalSolar.text = total.toString()+"L"
                                        binding.txtTotalSolarDiambil.text = ttl.toString()+"L"

                                        var ttlSolar = total+ttl
                                        var persentase = (total*100)/ttlSolar
                                        var pers2 = (ttl*100)/ttlSolar

                                        binding.numberOfCalories.text = String.format("%.0f", persentase).toString()+"%"
                                        binding.numberOfCalories2.text = String.format("%.0f", pers2).toString()+"%"
                                        var anim = ProgressBarAnimation()
                                        anim.ProgressBarAnimation(binding.statsProgressbar, 0.0F,String.format("%.0f", persentase).toFloat())
                                        anim.duration = 1000
                                        binding.statsProgressbar.startAnimation(anim)
                                        var anim2 = ProgressBarAnimation()
                                        anim2.ProgressBarAnimation(binding.statsProgressbar2, 0.0f,String.format("%.0f", pers2).toFloat())
                                        anim2.duration = 1000
                                        binding.statsProgressbar2.startAnimation(anim2)

                                    }else{
                                        binding.txtTotalSolar.text = "0L"
                                        binding.txtTotalSolarDiambil.text = "0L"

                                        binding.statsProgressbar.progress = 0
                                        binding.statsProgressbar2.progress = 0
                                        binding.numberOfCalories.text = "0%"
                                        binding.numberOfCalories2.text = "0%"
                                        var anim = ProgressBarAnimation()
                                        anim.ProgressBarAnimation(binding.statsProgressbar, 0.0F,0.0F)
                                        anim.duration = 1000
                                        binding.statsProgressbar.startAnimation(anim)
                                        var anim2 = ProgressBarAnimation()
                                        anim2.ProgressBarAnimation(binding.statsProgressbar2, 0.0f,0.0F)
                                        anim2.duration = 1000
                                        binding.statsProgressbar2.startAnimation(anim2)


                                        Toast.makeText(getApplicationContext(),"Data di Site ini kosong" ,
                                            Toast.LENGTH_LONG).show()
                                    }
                                }else{
                                    Toast.makeText(getApplicationContext(), response.message() ,
                                        Toast.LENGTH_LONG).show()
                                }
                            }
                        override fun onFailure(call: Call<PengambilanSolarResponse>, t: Throwable) {
                            t.message?.let { Log.d("error Server", it) }
                        }

                    })

                }
            }

            override fun onNothingSelected(p0: AdapterView<*>?) {

            }

        }
    }
    override fun onCreateOptionsMenu(menu: Menu): Boolean {
        menuInflater.inflate(R.menu.menu, menu)
        return true
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        return when (item.itemId) {
            R.id.action_profil -> {
                val intent = Intent(this, Profil::class.java)
                startActivity(intent)
                return true
            }
            R.id.action_logout ->{
                sharedPref.logout()
                val intent = Intent(this, LoginActivity::class.java)
                startActivity(intent)
                finish()
                return true
            }
            else -> super.onOptionsItemSelected(item)
        }
    }


}